@@ -218,7 +218,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
                 popup->addAction(autoSpellCheckAction);
 
                 if (checkSpellingEnabled() && d->activateLanguageMenu) {
-                    QMenu *languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
+                    auto languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
                     auto languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
@@ -452,7 +452,7 @@ void RichTextEditor::checkSpelling(bool force)
         backgroundSpellCheck->changeLanguage(d->spellCheckingLanguage);
     }
     if (!d->ignoreSpellCheckingWords.isEmpty()) {
-        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
+        for (const QString &word : std::as_const(d->ignoreSpellCheckingWords)) {
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
@@ -564,7 +564,7 @@ void RichTextEditor::addIgnoreWordsToHighLighter()
     }
     if (d->richTextDecorator) {
         Sonnet::Highlighter *_highlighter = d->richTextDecorator->highlighter();
-        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
+        for (const QString &word : std::as_const(d->ignoreSpellCheckingWords)) {
             _highlighter->ignoreWord(word);
         }
     }
@@ -722,9 +722,10 @@ bool RichTextEditor::event(QEvent *ev)
 void RichTextEditor::wheelEvent(QWheelEvent *event)
 {
     if (QApplication::keyboardModifiers() & Qt::ControlModifier) {
-        if (event->angleDelta().y() > 0) {
+        const int angleDeltaY{event->angleDelta().y()};
+        if (angleDeltaY > 0) {
             zoomIn();
-        } else if (event->angleDelta().y() < 0) {
+        } else if (angleDeltaY < 0) {
             zoomOut();
         }
         event->accept();
@@ -938,7 +939,7 @@ void RichTextEditor::keyPressEvent(QKeyEvent *event)
 int RichTextEditor::zoomFactor() const
 {
     int pourcentage = 100;
-    QFont f = font();
+    const QFont f = font();
     if (d->mInitialFontSize != f.pointSize()) {
         pourcentage = (f.pointSize() * 100) / d->mInitialFontSize;
     }
