@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,9 +24,12 @@ TextToSpeechInterface::TextToSpeechInterface(TextToSpeechWidget *textToSpeechWid
     : AbstractTextToSpeechInterface(parent)
     , d(new KPIMTextEdit::TextToSpeechInterfacePrivate(textToSpeechWidget))
 {
-    KPIMTextEdit::TextToSpeech::self(); //init
+    KPIMTextEdit::TextToSpeech::self(); // init
     connect(d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::stateChanged, this, &TextToSpeechInterface::stateChanged);
-    connect(KPIMTextEdit::TextToSpeech::self(), &KPIMTextEdit::TextToSpeech::stateChanged, d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::slotStateChanged);
+    connect(KPIMTextEdit::TextToSpeech::self(),
+            &KPIMTextEdit::TextToSpeech::stateChanged,
+            d->mTextToSpeechWidget,
+            &KPIMTextEdit::TextToSpeechWidget::slotStateChanged);
 }
 
 TextToSpeechInterface::~TextToSpeechInterface()
